from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Graphic = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'Logo_Open_Hardware_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Logo_Open_Hardware_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'Logo', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nLogo_Open_Hardware_Large\n\nLogo', 'unit_defs':[] }),
        Part(**{ 'name':'Logo_Open_Hardware_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Logo_Open_Hardware_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'Logo', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nLogo_Open_Hardware_Small\n\nLogo' }),
        Part(**{ 'name':'SYM_Arrow45_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow45_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow angled 45Â°', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow45_Large\n\nsymbol arrow angled 45Â°' }),
        Part(**{ 'name':'SYM_Arrow45_Normal', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow45_Normal'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow angled 45Â°', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow45_Normal\n\nsymbol arrow angled 45Â°' }),
        Part(**{ 'name':'SYM_Arrow45_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow45_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow angled 45Â°', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow45_Small\n\nsymbol arrow angled 45Â°' }),
        Part(**{ 'name':'SYM_Arrow45_Tiny', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow45_Tiny'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow angled 45Â°', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow45_Tiny\n\nsymbol arrow angled 45Â°' }),
        Part(**{ 'name':'SYM_Arrow45_XLarge', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow45_XLarge'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow 45Â° angled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow45_XLarge\n\nsymbol arrow 45Â° angled' }),
        Part(**{ 'name':'SYM_Arrow_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow_Large\n\nsymbol arrow' }),
        Part(**{ 'name':'SYM_Arrow_Normal', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow_Normal'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow_Normal\n\nsymbol arrow' }),
        Part(**{ 'name':'SYM_Arrow_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow_Small\n\nsymbol arrow' }),
        Part(**{ 'name':'SYM_Arrow_Tiny', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow_Tiny'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow_Tiny\n\nsymbol arrow' }),
        Part(**{ 'name':'SYM_Arrow_XLarge', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow_XLarge'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow_XLarge\n\nsymbol arrow' }),
        Part(**{ 'name':'SYM_ESD_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_ESD_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol ESD', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_ESD_Large\n\nsymbol ESD' }),
        Part(**{ 'name':'SYM_ESD_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_ESD_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol ESD', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_ESD_Small\n\nsymbol ESD' }),
        Part(**{ 'name':'SYM_Earth_Protective_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Earth_Protective_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'graphical symbol earth protective', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Earth_Protective_Large\n\ngraphical symbol earth protective' }),
        Part(**{ 'name':'SYM_Earth_Protective_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Earth_Protective_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'graphical symbol earth protective', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Earth_Protective_Small\n\ngraphical symbol earth protective' }),
        Part(**{ 'name':'SYM_EasterEgg_42x60mm', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_EasterEgg_42x60mm'}), 'ref_prefix':'SYM', 'fplist':['Symbol:EasterEgg_EWG1308-2013_ClassA'], 'footprint':'Symbol:EasterEgg_EWG1308-2013_ClassA', 'keywords':'egg easter oval', 'description':'', 'datasheet':'https://eur-lex.europa.eu/LexUriServ/LexUriServ.do?uri=OJ:L:2013:347:0671:0854:de:PDF', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_EasterEgg_42x60mm\n\negg easter oval' }),
        Part(**{ 'name':'SYM_Flash_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Flash_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'graphic symbol flash VAC 220VAC 110VAC power', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Flash_Large\n\ngraphic symbol flash VAC 220VAC 110VAC power' }),
        Part(**{ 'name':'SYM_Flash_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Flash_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'graphic symbol flash VAC 220VAC 110VAC power', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Flash_Small\n\ngraphic symbol flash VAC 220VAC 110VAC power' }),
        Part(**{ 'name':'SYM_Flash_XLarge', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Flash_XLarge'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'graphic symbol flash VAC 220VAC 110VAC power', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Flash_XLarge\n\ngraphic symbol flash VAC 220VAC 110VAC power' }),
        Part(**{ 'name':'SYM_Hot_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Hot_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo hot surface warning heat', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Hot_Large\n\nsymbol logo hot surface warning heat' }),
        Part(**{ 'name':'SYM_Hot_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Hot_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo hot surface warning heat', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Hot_Small\n\nsymbol logo hot surface warning heat' }),
        Part(**{ 'name':'SYM_LASER_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_LASER_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo laser warning', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_LASER_Large\n\nsymbol logo laser warning' }),
        Part(**{ 'name':'SYM_LASER_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_LASER_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo laser warning', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_LASER_Small\n\nsymbol logo laser warning' }),
        Part(**{ 'name':'SYM_Magnet_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Magnet_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo magnetic field warning', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Magnet_Large\n\nsymbol logo magnetic field warning' }),
        Part(**{ 'name':'SYM_Magnet_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Magnet_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo magnetic field warning', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Magnet_Small\n\nsymbol logo magnetic field warning' }),
        Part(**{ 'name':'SYM_Radio_Waves_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Radio_Waves_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo radio waves warning radiation', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Radio_Waves_Large\n\nsymbol logo radio waves warning radiation' }),
        Part(**{ 'name':'SYM_Radio_Waves_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Radio_Waves_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo radio waves warning radiation', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Radio_Waves_Small\n\nsymbol logo radio waves warning radiation' }),
        Part(**{ 'name':'SYM_Radioactive_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Radioactive_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo radioactive radiation warning heat', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Radioactive_Large\n\nsymbol logo radioactive radiation warning heat' }),
        Part(**{ 'name':'SYM_Radioactive_Radiation_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Radioactive_Radiation_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo radioactive radiation warning', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Radioactive_Radiation_Small\n\nsymbol logo radioactive radiation warning' })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_Parallax = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'P8X32A-D40', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'P8X32A-D40'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'microcontroller multicore Parallax Propeller DIP', 'description':'', 'datasheet':'https://www.parallax.com/sites/default/files/downloads/P8X32A-Propeller-Datasheet-v1.4.0_0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Parallax.kicad_sym\nP8X32A-D40\n\nmicrocontroller multicore Parallax Propeller DIP', 'pins':[
            Pin(num='1',name='P0',func=pin_types.BIDIR),
            Pin(num='10',name='~{BOE}',func=pin_types.INPUT),
            Pin(num='11',name='~{RES}',func=pin_types.BIDIR),
            Pin(num='12',name='VDD',func=pin_types.PWRIN),
            Pin(num='13',name='P8',func=pin_types.BIDIR),
            Pin(num='14',name='P9',func=pin_types.BIDIR),
            Pin(num='15',name='P10',func=pin_types.BIDIR),
            Pin(num='16',name='P11',func=pin_types.BIDIR),
            Pin(num='17',name='P12',func=pin_types.BIDIR),
            Pin(num='18',name='P13',func=pin_types.BIDIR),
            Pin(num='19',name='P14',func=pin_types.BIDIR),
            Pin(num='2',name='P1',func=pin_types.BIDIR),
            Pin(num='20',name='P15',func=pin_types.BIDIR),
            Pin(num='21',name='P16',func=pin_types.BIDIR),
            Pin(num='22',name='P17',func=pin_types.BIDIR),
            Pin(num='23',name='P18',func=pin_types.BIDIR),
            Pin(num='24',name='P19',func=pin_types.BIDIR),
            Pin(num='25',name='P20',func=pin_types.BIDIR),
            Pin(num='26',name='P21',func=pin_types.BIDIR),
            Pin(num='27',name='P22',func=pin_types.BIDIR),
            Pin(num='28',name='P23',func=pin_types.BIDIR),
            Pin(num='29',name='VSS',func=pin_types.PWRIN),
            Pin(num='3',name='P2',func=pin_types.BIDIR),
            Pin(num='30',name='XI',func=pin_types.INPUT),
            Pin(num='31',name='XO',func=pin_types.OUTPUT),
            Pin(num='32',name='VDD',func=pin_types.PWRIN),
            Pin(num='33',name='P24',func=pin_types.BIDIR),
            Pin(num='34',name='P25',func=pin_types.BIDIR),
            Pin(num='35',name='P26',func=pin_types.BIDIR),
            Pin(num='36',name='P27',func=pin_types.BIDIR),
            Pin(num='37',name='P28',func=pin_types.BIDIR),
            Pin(num='38',name='P29',func=pin_types.BIDIR),
            Pin(num='39',name='P30',func=pin_types.BIDIR),
            Pin(num='4',name='P3',func=pin_types.BIDIR),
            Pin(num='40',name='P31',func=pin_types.BIDIR),
            Pin(num='5',name='P4',func=pin_types.BIDIR),
            Pin(num='6',name='P5',func=pin_types.BIDIR),
            Pin(num='7',name='P6',func=pin_types.BIDIR),
            Pin(num='8',name='P7',func=pin_types.BIDIR),
            Pin(num='9',name='VSS',func=pin_types.PWRIN)], 'unit_defs':[] }),
        Part(**{ 'name':'P8X32A-M44', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'P8X32A-M44'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_9x9mm_P0.65mm_EP7.5x7.5mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_9x9mm_P0.65mm_EP7.5x7.5mm', 'keywords':'microcontroller multicore Parallax Propeller QFN', 'description':'', 'datasheet':'https://www.parallax.com/sites/default/files/downloads/P8X32A-Propeller-Datasheet-v1.4.0_0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Parallax.kicad_sym\nP8X32A-M44\n\nmicrocontroller multicore Parallax Propeller QFN', 'pins':[
            Pin(num='1',name='P4',func=pin_types.BIDIR),
            Pin(num='10',name='P9',func=pin_types.BIDIR),
            Pin(num='11',name='P10',func=pin_types.BIDIR),
            Pin(num='12',name='P11',func=pin_types.BIDIR),
            Pin(num='13',name='P12',func=pin_types.BIDIR),
            Pin(num='14',name='P13',func=pin_types.BIDIR),
            Pin(num='15',name='P14',func=pin_types.BIDIR),
            Pin(num='16',name='P15',func=pin_types.BIDIR),
            Pin(num='17',name='VSS',func=pin_types.PWRIN),
            Pin(num='18',name='VDD',func=pin_types.PWRIN),
            Pin(num='19',name='P16',func=pin_types.BIDIR),
            Pin(num='2',name='P5',func=pin_types.BIDIR),
            Pin(num='20',name='P17',func=pin_types.BIDIR),
            Pin(num='21',name='P18',func=pin_types.BIDIR),
            Pin(num='22',name='P19',func=pin_types.BIDIR),
            Pin(num='23',name='P20',func=pin_types.BIDIR),
            Pin(num='24',name='P21',func=pin_types.BIDIR),
            Pin(num='25',name='P22',func=pin_types.BIDIR),
            Pin(num='26',name='P23',func=pin_types.BIDIR),
            Pin(num='27',name='VSS',func=pin_types.PWRIN),
            Pin(num='28',name='XI',func=pin_types.INPUT),
            Pin(num='29',name='XO',func=pin_types.OUTPUT),
            Pin(num='3',name='P6',func=pin_types.BIDIR),
            Pin(num='30',name='VDD',func=pin_types.PWRIN),
            Pin(num='31',name='P24',func=pin_types.BIDIR),
            Pin(num='32',name='P25',func=pin_types.BIDIR),
            Pin(num='33',name='P26',func=pin_types.BIDIR),
            Pin(num='34',name='P27',func=pin_types.BIDIR),
            Pin(num='35',name='P28',func=pin_types.BIDIR),
            Pin(num='36',name='P29',func=pin_types.BIDIR),
            Pin(num='37',name='P30',func=pin_types.BIDIR),
            Pin(num='38',name='P31',func=pin_types.BIDIR),
            Pin(num='39',name='VSS',func=pin_types.PWRIN),
            Pin(num='4',name='P7',func=pin_types.BIDIR),
            Pin(num='40',name='VDD',func=pin_types.PWRIN),
            Pin(num='41',name='P0',func=pin_types.BIDIR),
            Pin(num='42',name='P1',func=pin_types.BIDIR),
            Pin(num='43',name='P2',func=pin_types.BIDIR),
            Pin(num='44',name='P3',func=pin_types.BIDIR),
            Pin(num='45',name='VSS',func=pin_types.PWRIN),
            Pin(num='5',name='VSS',func=pin_types.PWRIN),
            Pin(num='6',name='~{BOE}',func=pin_types.INPUT),
            Pin(num='7',name='~{RES}',func=pin_types.BIDIR),
            Pin(num='8',name='VDD',func=pin_types.PWRIN),
            Pin(num='9',name='P8',func=pin_types.BIDIR)], 'unit_defs':[] }),
        Part(**{ 'name':'P8X32A-Q44', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'P8X32A-Q44'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'keywords':'microcontroller multicore Parallax Propeller LQFP', 'description':'', 'datasheet':'https://www.parallax.com/sites/default/files/downloads/P8X32A-Propeller-Datasheet-v1.4.0_0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Parallax.kicad_sym\nP8X32A-Q44\n\nmicrocontroller multicore Parallax Propeller LQFP', 'pins':[
            Pin(num='1',name='P4',func=pin_types.BIDIR),
            Pin(num='10',name='P9',func=pin_types.BIDIR),
            Pin(num='11',name='P10',func=pin_types.BIDIR),
            Pin(num='12',name='P11',func=pin_types.BIDIR),
            Pin(num='13',name='P12',func=pin_types.BIDIR),
            Pin(num='14',name='P13',func=pin_types.BIDIR),
            Pin(num='15',name='P14',func=pin_types.BIDIR),
            Pin(num='16',name='P15',func=pin_types.BIDIR),
            Pin(num='17',name='VSS',func=pin_types.PWRIN),
            Pin(num='18',name='VDD',func=pin_types.PWRIN),
            Pin(num='19',name='P16',func=pin_types.BIDIR),
            Pin(num='2',name='P5',func=pin_types.BIDIR),
            Pin(num='20',name='P17',func=pin_types.BIDIR),
            Pin(num='21',name='P18',func=pin_types.BIDIR),
            Pin(num='22',name='P19',func=pin_types.BIDIR),
            Pin(num='23',name='P20',func=pin_types.BIDIR),
            Pin(num='24',name='P21',func=pin_types.BIDIR),
            Pin(num='25',name='P22',func=pin_types.BIDIR),
            Pin(num='26',name='P23',func=pin_types.BIDIR),
            Pin(num='27',name='VSS',func=pin_types.PWRIN),
            Pin(num='28',name='XI',func=pin_types.INPUT),
            Pin(num='29',name='XO',func=pin_types.OUTPUT),
            Pin(num='3',name='P6',func=pin_types.BIDIR),
            Pin(num='30',name='VDD',func=pin_types.PWRIN),
            Pin(num='31',name='P24',func=pin_types.BIDIR),
            Pin(num='32',name='P25',func=pin_types.BIDIR),
            Pin(num='33',name='P26',func=pin_types.BIDIR),
            Pin(num='34',name='P27',func=pin_types.BIDIR),
            Pin(num='35',name='P28',func=pin_types.BIDIR),
            Pin(num='36',name='P29',func=pin_types.BIDIR),
            Pin(num='37',name='P30',func=pin_types.BIDIR),
            Pin(num='38',name='P31',func=pin_types.BIDIR),
            Pin(num='39',name='VSS',func=pin_types.PWRIN),
            Pin(num='4',name='P7',func=pin_types.BIDIR),
            Pin(num='40',name='VDD',func=pin_types.PWRIN),
            Pin(num='41',name='P0',func=pin_types.BIDIR),
            Pin(num='42',name='P1',func=pin_types.BIDIR),
            Pin(num='43',name='P2',func=pin_types.BIDIR),
            Pin(num='44',name='P3',func=pin_types.BIDIR),
            Pin(num='5',name='VSS',func=pin_types.PWRIN),
            Pin(num='6',name='~{BOE}',func=pin_types.INPUT),
            Pin(num='7',name='~{RES}',func=pin_types.BIDIR),
            Pin(num='8',name='VDD',func=pin_types.PWRIN),
            Pin(num='9',name='P8',func=pin_types.BIDIR)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

RF_Mixer = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'AD831AP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD831AP'}), 'ref_prefix':'U', 'fplist':['Package_LCC:PLCC-20'], 'footprint':'Package_LCC:PLCC-20', 'keywords':'mixer rf', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD831.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Mixer.kicad_sym\nAD831AP\n\nmixer rf', 'pins':[
            Pin(num='1',name='VP',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='LON',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='LOP',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VP',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='BIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VN',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='VFB',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AP',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IFN',func=pin_types.OPENCOLL,unit=1),
            Pin(num='20',name='IFP',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='AN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VN',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RFP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='RFN',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VP',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADE-6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADE-6'}), 'ref_prefix':'U', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_LandPatternPL-052'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_LandPatternPL-052', 'keywords':'mixer rf', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADE-6.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Mixer.kicad_sym\nADE-6\n\nmixer rf', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IF',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='RF',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='LO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADL5801', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADL5801'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-VQ-24-1EP_4x4mm_P0.5mm_EP2.642x2.642mm'], 'footprint':'Package_CSP:LFCSP-VQ-24-1EP_4x4mm_P0.5mm_EP2.642x2.642mm', 'keywords':'mixer active', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADL5801.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Mixer.kicad_sym\nADL5801\n\nmixer active', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VSET',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='DETO',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='VPDT',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='RFIN',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='RFIP',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VPRF',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='IFOP',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='IFON',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VPLO',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='LOIP',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='LOIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VPLO',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~{ENBL}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADL5802', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADL5802'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-24-1EP_4x4mm_P0.5mm_EP2.5x2.5mm'], 'footprint':'Package_CSP:LFCSP-24-1EP_4x4mm_P0.5mm_EP2.5x2.5mm', 'keywords':'mixer rf', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADL5802.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Mixer.kicad_sym\nADL5802\n\nmixer rf', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='LOIN',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VSET',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VPOS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='OP2-',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OP2+',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='RF2-',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='RF2+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='RF1-',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='RF1+',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VPOS',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OP1+',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='OP1-',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VPOS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~{ENBL}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='LOIP',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HMC213A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HMC213A'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'mixer active', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/hmc213a.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Mixer.kicad_sym\nHMC213A\n\nmixer active', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='LO',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='IF',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='RF',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT5560', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT5560'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_3x3mm_P0.5mm_EP1.66x2.38mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_3x3mm_P0.5mm_EP1.66x2.38mm', 'keywords':'rf mixer', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/5560f.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Mixer.kicad_sym\nLT5560\n\nrf mixer', 'pins':[
            Pin(num='1',name='LO-',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='OUT-',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='OUT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='LO+',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADEX-10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADEX-10'}), 'ref_prefix':'U', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_LandPatternPL-052', 'RF_Mini-Circuits:Mini-Circuits_CD542_LandPatternPL-052'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_LandPatternPL-052', 'keywords':'mixer rf', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADEX-10.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Mixer.kicad_sym\nADEX-10\n\nmixer rf', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IF',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='RF',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='LO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HMC213B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HMC213B'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'mixer active', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/hmc213B.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Mixer.kicad_sym\nHMC213B\n\nmixer active', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='LO',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='IF',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='RF',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])